@@ -38,7 +38,7 @@ XML_FILENAME = 'facebook.xml'
 
 def run_api(api_key, max_minutes, max_characters, max_items):
     max_file_age = 60 * max_minutes
-    xml_temp_path = os.path.join(TEMP_FOLDER, NAME, filename)
+    xml_temp_path = os.path.join(TEMP_FOLDER, NAME, XML_FILENAME)
 
     headers = {
         'Authorization': 'Token {}'.format(api_key)
@@ -66,7 +66,7 @@ def run_api(api_key, max_minutes, max_characters, max_items):
             if thumbnail_url is None:
                 media_link = 'Content:\\placeholders\\img.png'
             else:
-                media_link = download_install_media(thumbnail_url, TEMP_FOLDER, NAME, thumbnail_name)
+                media_link = download_install_media(thumbnail_url, TEMP_FOLDER, NAME)
             
             ET.SubElement(item, "image").text = media_link
 
